@@ -41,7 +41,7 @@
 #endif
 
 static PyObject *PGError;
-static const char *PyPgVersion = "3.4";
+static const char *PyPgVersion = "3.5 (beta)";
 
 /* taken from fileobject.c */
 #define BUF(v) PyString_AS_STRING((PyStringObject *)(v))
@@ -91,6 +91,12 @@ const char *__movename[5] =
 #define NO_SNPRINTF 1
 #endif
 
+/* In 7.4 PQfreeNotify was deprecated and PQfreemem is used instead.  A
+   macro exists in 7.4 for backwards compatibility. */
+#ifndef PQfreeNotify	/* must be earlier than 7.4 */
+#define PQfreemem PQfreeNotify
+#endif
+
 /* --------------------------------------------------------------------- */
 
 /* MODULE GLOBAL VARIABLES */
@@ -1818,7 +1824,7 @@ pgquery_getresult(pgqueryobject * self, PyObject * args)
 						break;
 
 					case 2:
-						val = PyLong_FromLong(strtol(s, NULL, 10));
+						val = PyLong_FromLongLong(strtoll(s, NULL, 10));
 						break;
 
 					case 3:
@@ -1940,7 +1946,7 @@ pgquery_dictresult(pgqueryobject * self, PyObject * args)
 						break;
 
 					case 2:
-						val = PyLong_FromLong(strtol(s, NULL, 10));
+						val = PyLong_FromLongLong(strtoll(s, NULL, 10));
 						break;
 
 					case 3:
@@ -2172,7 +2178,7 @@ pg_query(pgobject * self, PyObject * args)
 				}
 
 				/* otherwise, return the oid */
-				return PyInt_FromLong(oid);
+				return PyLong_FromLongLong(oid);
 
 			case PGRES_COPY_OUT:		/* no data will be received */
 			case PGRES_COPY_IN:
